#
# spec file for package python-rpm
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2017 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Enable Python build sourced from rpm spec
%global with_python 1
Name:           python-rpm
Version:        4.19.1.1
Release:        4.1
Summary:        Python Bindings for Manipulating RPM Packages
License:        GPL-2.0-or-later
Group:          Development/Libraries/Python
URL:            https://rpm.org/
#Git-Clone:     https://github.com/rpm-software-management/rpm
BuildRequires:  %{python_module devel}
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  file-devel
BuildRequires:  libacl-devel
BuildRequires:  libbz2-devel
BuildRequires:  libcap-devel
BuildRequires:  libdw-devel
BuildRequires:  libelf-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libselinux-devel
BuildRequires:  libsemanage-devel
BuildRequires:  libtool
BuildRequires:  lua-devel
BuildRequires:  ncurses-devel
BuildRequires:  popt-devel
BuildRequires:  python-rpm-macros
BuildRequires:  xz-devel
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(libzstd)
Requires:       rpm = %{version}
%{expand:%(sed -n -e '/^Source:/,/^BuildRoot:/p' <%{_sourcedir}/rpm.spec)}
Source99:       rpm.spec
%if "%{python_flavor}" == "python2"
Obsoletes:      rpm-python < %{version}-%{release}
Provides:       rpm-python = %{version}-%{release}
%endif
%python_subpackages

%description
This package contains a module that permits applications written in
the Python programming language to use the interface supplied by
RPM Package Manager libraries.

This package should be installed if you want to develop Python programs
that will manipulate RPM packages and databases.

%prep
%{expand:%(sed -n -e '/^%%prep/,/^%%install/p' <%{_sourcedir}/rpm.spec | sed -e '1d' -e '$d')}

%install
cd _build
%{python_expand #
cmake ..  -U\*Python3\* -DWITH_PYTHON_VERSION=%{$python_version}
make DESTDIR=%{buildroot} -C python clean
make DESTDIR=%{buildroot} -C python install
}

%python_compileall
rm -rf %{buildroot}/%{_defaultdocdir}/%{NAME}

%files %{python_files}
%{python_sitearch}/rpm
%{python_sitearch}/rpm-%{version}*-info

%changelog
* Fri Feb  9 2024 mls@suse.de
- update to rpm-4.19.1.1
* Thu Feb  1 2024 mls@suse.de
- Use cmake for compiling and installing the python modules
  * Drop python_setup.diff
  * Add cmake_python_version.diff
* Thu Feb  1 2024 Dirk Müller <dmueller@suse.com>
- buildrequire setuptools
* Mon Oct 30 2023 Matej Cepl <mcepl@cepl.eu>
- Modernize python-rpm.spec to stop using deprecated macros
  (%%python_build and %%python_install).
* Wed Oct 11 2023 mls@suse.de
- update to rpm-4.19.1
* Tue May 30 2023 Jiri Srain <jsrain@suse.com>
- add _multibuild for multiple .spec-files
* Fri Dec  2 2022 mls@suse.de
- update to rpm-4.18.0
* Thu Jul 21 2022 mls@suse.de
- update to rpm-4.17.1
* Thu Sep 23 2021 mls@suse.de
- update to rpm-4.17.0
* Tue Mar 30 2021 mls@suse.de
- update to rpm-4.16.1.3
* Wed Sep 30 2020 mls@suse.de
- update to rpm-4.16.0
* Tue Nov 19 2019 mls@suse.de
- update to rpm-4.15.1
* Wed Oct  2 2019 mls@suse.de
- update to rpm-4.15.0
* Thu Nov 22 2018 asmorodskyi@suse.com
- Fix python-module compatibility with older distros
* Fri Apr  6 2018 mls@suse.de
- remove rpmlint-Factory buildignore
* Tue Mar 20 2018 tchvatal@suse.com
- Switch really to singlespec thus allowing us to build without
  python2-devel present in the distribution
* Wed Jan 31 2018 mls@suse.de
- update to rpm-4.14.1
* Tue Dec 19 2017 jengelh@inai.de
- Update RPM groups
* Sat Oct 28 2017 ngompa13@gmail.com
- Add a comment to note that prep and build stages come from rpm.spec
* Mon Oct 16 2017 ngompa13@gmail.com
- Properly quote the conditional for Obsoletes+Provides
* Sun Oct 15 2017 ngompa13@gmail.com
- Unify rpm-python and python3-rpm into singlespec
- Switch the build to use setuptools-based build, so that
  the Python module is properly built with all its metadata
* Wed Nov 20 2013 mls@suse.de
- adapt to python-3.3, which no longer looks at XXXmodule.so
* Fri Jul 12 2013 mls@suse.de
- update to rpm-4.11.1
* Wed Jan  2 2013 dmueller@suse.com
- Update to 4.10.2
* Mon Apr 23 2012 mls@suse.de
- modified capsule api diff to match rpm upstream
* Wed Apr 11 2012 klaussfreire@gmail.com
- Fix usage of deprecated AsVoidPtr Python/C API,
  replaced by Capsule API
* Tue Jan 17 2012 saschpe@suse.de
- Spec file cleanup:
  * Don't rm -rf %%{buildroot}
  * Removed %%clean section
  * Removed authors from description
* Sun Dec 11 2011 coolo@suse.com
- add libtool as explicit buildrequire
* Wed Feb 23 2011 mls@suse.de
- drop standard python directories from filelist [bnc#229189]
* Fri Oct 22 2010 coolo@novell.com
- adapt second spec file to changes done to rpm.spec
* Mon Oct 18 2010 dmueller@suse.de
- adapt buildrequires
* Thu Feb 12 2009 ro@suse.de
- adapt buildrequires
* Wed Oct  8 2008 cthiel@suse.de
- added libelf-devel to BuildRequires to fix build
* Thu Sep 11 2008 mls@suse.de
- update to 4.4.2.3 to get rid of >50 patches
* Sat Aug 30 2008 cthiel@suse.de
- add libselinux-devel to BuildRequires
* Thu Aug  7 2008 dmueller@suse.de
- fix build against python 2.6
* Thu Mar 27 2008 coolo@suse.de
- fix buildrequires
* Fri May 25 2007 mls@suse.de
- fix unicode queries
* Fri Mar 30 2007 rguenther@suse.de
- add ncurses-devel and zlib-devel BuildRequires.
* Wed Oct 18 2006 mls@suse.de
- use rpm.spec for building instead of duplication everything
- delete superfluous .a and .la files [#202604]
- create .pyc and .pyo files [#205711]
* Sun Oct 15 2006 schwab@suse.de
- Make sure config.rpath is present.
* Fri Sep 22 2006 aj@suse.de
- Fix for python2.5.
* Thu Sep 21 2006 lnussel@suse.de
- do not package beecrypt python bindings as libbeecrypt is not
  packaged either
- fix literal %%{version} in Requires tag
* Thu Sep 21 2006 lnussel@suse.de
- fix build with python 2.5 by overriding autodetection
* Tue Sep 19 2006 rguenther@suse.de
- split from rpm package
